"""Mitype"""

from mitype.app import App

if __name__ == "__main__":
    App()
